---
examples:
 - name: basic
   label: Basic Badge
   description: Basic badges with custom labels.
 - name: icon
   label: Badges with Icons
   description: Basic badges with icons.
---
A `lightning-badge` is a label that holds small amounts of information. A
badge can be used to display unread notifications, or to label a block of
text. Badges don't work for navigation because they can't include a hyperlink.

This component inherits styling from
[badges](https://www.lightningdesignsystem.com/components/badges/) in the
Lightning Design System.

You can create two types of badges.
 * A text-only badge
 * A badge with an icon that's displayed before or after the text

Visit [icons](https://lightningdesignsystem.com/icons) to view the available icons.

When applying Lightning Design System classes or icons, check that they are
available in the Lightning Design System release tied to your org. The latest
Lightning Design System resources become available only when the new release
is available in your org.

Here is an example of a text-only badge.

```html
<template>
    <lightning-badge label="Account Name">
    </lightning-badge>
</template>
```

To create a badge with an icon, set the `icon-name` to a Lightning Design System icon. The icon is displayed before the text by default.

```html
<template>
    <lightning-badge 
        label="Account Name" 
        icon-name="standard:account">
    </lightning-badge>
</template>
```

To display the icon after the text, set `icon-position="end"`.

```html
<template>
    <lightning-badge 
        label="Starred Accounts" 
        icon-name="custom:custom11" 
        icon-position="end">
    </lightning-badge>
</template>
```

To display a color badge, use the Lightning Design System classes.
See [colors](https://www.lightningdesignsystem.com/components/badges/#Colors) for more information.

```html
<template>
    <lightning-badge
        label="Gamma"
        class="slds-badge_inverse">
    </lightning-badge>
</template>
```


#### Usage Considerations

Badges with nested elements are not supported. To create a label that can contain links, use `lightning-pill` instead.







