/*  *******************************************************************************************
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createWireAdapterConstructor } from 'force/ldsBindings';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, freeze: ObjectFreeze } = Object;
const { isArray: ArrayIsArray } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    headers: {
        'Cache-Control': 'no-cache',
    },
};
const keyPrefix = 'CMS::';

const { freeze: ObjectFreeze$1, keys: ObjectKeys$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
const { stringify: JSONStrinify } = JSON;
function createLink(ref) {
    return {
        __ref: ref,
    };
}

function validate(obj, path = 'ManagedContentChannelRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_channelId = obj.channelId;
        const path_channelId = path + '.channelId';
        if (typeof obj_channelId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_channelId + '" (at "' + path_channelId + '")');
        }
        const obj_channelName = obj.channelName;
        const path_channelName = path + '.channelName';
        if (typeof obj_channelName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_channelName + '" (at "' + path_channelName + '")');
        }
        const obj_channelType = obj.channelType;
        const path_channelType = path + '.channelType';
        if (typeof obj_channelType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_channelType + '" (at "' + path_channelType + '")');
        }
        const obj_isChannelSearchable = obj.isChannelSearchable;
        const path_isChannelSearchable = path + '.isChannelSearchable';
        if (typeof obj_isChannelSearchable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isChannelSearchable + '" (at "' + path_isChannelSearchable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze(input) {
    ObjectFreeze$1(input);
}

function validate$1(obj, path = 'ManagedContentChannelCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_channels = obj.channels;
        const path_channels = path + '.channels';
        if (!ArrayIsArray$1(obj_channels)) {
            return new TypeError('Expected "array" but received "' + typeof obj_channels + '" (at "' + path_channels + '")');
        }
        for (let i = 0; i < obj_channels.length; i++) {
            const obj_channels_item = obj_channels[i];
            const path_channels_item = path_channels + '[' + i + ']';
            const referenceManagedContentChannelRepresentationValidationError = validate(obj_channels_item, path_channels_item);
            if (referenceManagedContentChannelRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ManagedContentChannelRepresentation (at "' + path_channels_item + '")\n';
                message += referenceManagedContentChannelRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        if (typeof obj_nextPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        if (typeof obj_previousPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
        }
        const obj_totalChannels = obj.totalChannels;
        const path_totalChannels = path + '.totalChannels';
        if (typeof obj_totalChannels !== 'number' || (typeof obj_totalChannels === 'number' && Math.floor(obj_totalChannels) !== obj_totalChannels)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_totalChannels + '" (at "' + path_totalChannels + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize(input, existing, path, lds, store, timestamp) {
    return input;
}
const select = function ManagedContentChannelCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$1(input) {
    const input_channels = input.channels;
    for (let i = 0; i < input_channels.length; i++) {
        const input_channels_item = input_channels[i];
        deepFreeze(input_channels_item);
    }
    ObjectFreeze$1(input_channels);
    ObjectFreeze$1(input);
}
const ingest = function ManagedContentChannelCollectionRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$1(input);
    if (existingRecord === undefined || equals(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$1(lds, params) {
    return select();
}
function keyBuilder(params) {
    return keyPrefix + 'ManagedContentChannelCollectionRepresentation(' + 'page:' + params.queryParams.page + ',' + 'pageSize:' + params.queryParams.pageSize + ')';
}
function ingestSuccess(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError(lds, params, error, snapshotRefresh) {
    const key = keyBuilder(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/connect/cms/delivery/channels',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: config.queryParams,
        ingest: ingest,
        headers,
    };
}

const adapterName = 'getDeliveryChannels';
const getDeliveryChannels_ConfigPropertyNames = {
    displayName: 'getDeliveryChannels',
    parameters: {
        required: [],
        optional: ['page', 'pageSize']
    }
};
function createResourceParams(config) {
    return {
        queryParams: {
            page: config.page, pageSize: config.pageSize
        }
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_page = untrustedConfig.page;
    if (typeof untrustedConfig_page === 'number' && Math.floor(untrustedConfig_page) === untrustedConfig_page) {
        config.page = untrustedConfig_page;
    }
    const untrustedConfig_pageSize = untrustedConfig.pageSize;
    if (typeof untrustedConfig_pageSize === 'number' && Math.floor(untrustedConfig_pageSize) === untrustedConfig_pageSize) {
        config.pageSize = untrustedConfig_pageSize;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot(lds, config) {
    const resourceParams = createResourceParams(config);
    const selector = {
        recordId: keyBuilder(resourceParams),
        node: select$1(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError(lds, config, resourceParams, response) {
    const snapshot = ingestError(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot(lds, config, override) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot(lds, config, snapshot) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
const getDeliveryChannelsAdapterFactory = (lds) => function getDeliveryChannels(untrustedConfig) {
    const config = validateAdapterConfig(untrustedConfig, getDeliveryChannels_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot(lds, config);
};

var DiscriminatorValues;
(function (DiscriminatorValues) {
    DiscriminatorValues["Date"] = "Date";
    DiscriminatorValues["Media"] = "Media";
    DiscriminatorValues["Text"] = "Text";
    DiscriminatorValues["DateTime"] = "DateTime";
})(DiscriminatorValues || (DiscriminatorValues = {}));
function validate$2(obj, path = 'ManagedContentNodeValueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_nodeType = obj.nodeType;
        const path_nodeType = path + '.nodeType';
        if (typeof obj_nodeType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_nodeType + '" (at "' + path_nodeType + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$2(input) {
    ObjectFreeze$1(input);
}

function validate$3(obj, path = 'ManagedContentVersionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_contentNodes = obj.contentNodes;
        const path_contentNodes = path + '.contentNodes';
        if (typeof obj_contentNodes !== 'object' || ArrayIsArray$1(obj_contentNodes) || obj_contentNodes === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_contentNodes + '" (at "' + path_contentNodes + '")');
        }
        const obj_contentNodes_keys = ObjectKeys$1(obj_contentNodes);
        for (let i = 0; i < obj_contentNodes_keys.length; i++) {
            const key = obj_contentNodes_keys[i];
            const obj_contentNodes_prop = obj_contentNodes[key];
            const path_contentNodes_prop = path_contentNodes + '["' + key + '"]';
            const referenceManagedContentNodeValueRepresentationValidationError = validate$2(obj_contentNodes_prop, path_contentNodes_prop);
            if (referenceManagedContentNodeValueRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ManagedContentNodeValueRepresentation (at "' + path_contentNodes_prop + '")\n';
                message += referenceManagedContentNodeValueRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_contentUrlName = obj.contentUrlName;
        const path_contentUrlName = path + '.contentUrlName';
        if (typeof obj_contentUrlName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_contentUrlName + '" (at "' + path_contentUrlName + '")');
        }
        const obj_language = obj.language;
        const path_language = path + '.language';
        if (typeof obj_language !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_language + '" (at "' + path_language + '")');
        }
        const obj_managedContentId = obj.managedContentId;
        const path_managedContentId = path + '.managedContentId';
        if (typeof obj_managedContentId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_managedContentId + '" (at "' + path_managedContentId + '")');
        }
        const obj_publishedDate = obj.publishedDate;
        const path_publishedDate = path + '.publishedDate';
        if (typeof obj_publishedDate !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_publishedDate + '" (at "' + path_publishedDate + '")');
        }
        const obj_title = obj.title;
        const path_title = path + '.title';
        if (typeof obj_title !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_title + '" (at "' + path_title + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
        const obj_typeLabel = obj.typeLabel;
        const path_typeLabel = path + '.typeLabel';
        if (typeof obj_typeLabel !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_typeLabel + '" (at "' + path_typeLabel + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$3(input) {
    const input_contentNodes = input.contentNodes;
    const input_contentNodes_keys = Object.keys(input_contentNodes);
    const input_contentNodes_length = input_contentNodes_keys.length;
    for (let i = 0; i < input_contentNodes_length; i++) {
        const key = input_contentNodes_keys[i];
        const input_contentNodes_prop = input_contentNodes[key];
        deepFreeze$2(input_contentNodes_prop);
    }
    ObjectFreeze$1(input_contentNodes);
    ObjectFreeze$1(input);
}

function validate$4(obj, path = 'ManagedContentVersionCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_items = obj.items;
        const path_items = path + '.items';
        if (!ArrayIsArray$1(obj_items)) {
            return new TypeError('Expected "array" but received "' + typeof obj_items + '" (at "' + path_items + '")');
        }
        for (let i = 0; i < obj_items.length; i++) {
            const obj_items_item = obj_items[i];
            const path_items_item = path_items + '[' + i + ']';
            const referenceManagedContentVersionRepresentationValidationError = validate$3(obj_items_item, path_items_item);
            if (referenceManagedContentVersionRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ManagedContentVersionRepresentation (at "' + path_items_item + '")\n';
                message += referenceManagedContentVersionRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_total = obj.total;
        const path_total = path + '.total';
        if (typeof obj_total !== 'number' || (typeof obj_total === 'number' && Math.floor(obj_total) !== obj_total)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_total + '" (at "' + path_total + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize$1(input, existing, path, lds, store, timestamp) {
    return input;
}
const select$2 = function ManagedContentVersionCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals$1(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$4(input) {
    const input_items = input.items;
    for (let i = 0; i < input_items.length; i++) {
        const input_items_item = input_items[i];
        deepFreeze$3(input_items_item);
    }
    ObjectFreeze$1(input_items);
    ObjectFreeze$1(input);
}
const ingest$1 = function ManagedContentVersionCollectionRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$4(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize$1(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$4(input);
    if (existingRecord === undefined || equals$1(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$3(lds, params) {
    return select$2();
}
function keyBuilder$1(params) {
    return keyPrefix + 'ManagedContentVersionCollectionRepresentation(' + 'endDate:' + params.queryParams.endDate + ',' + 'includeMetadata:' + params.queryParams.includeMetadata + ',' + 'language:' + params.queryParams.language + ',' + 'managedContentIds:' + params.queryParams.managedContentIds + ',' + 'managedContentType:' + params.queryParams.managedContentType + ',' + 'page:' + params.queryParams.page + ',' + 'pageSize:' + params.queryParams.pageSize + ',' + 'startDate:' + params.queryParams.startDate + ',' + 'channelId:' + params.urlParams.channelId + ')';
}
function ingestSuccess$1(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$3(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError$1(lds, params, error, snapshotRefresh) {
    const key = keyBuilder$1(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest$1(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/connect/cms/delivery/channels/' + config.urlParams.channelId + '/contents/query',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest$1,
        headers,
    };
}

const adapterName$1 = 'listContent';
const listContent_ConfigPropertyNames = {
    displayName: 'listContent',
    parameters: {
        required: ['channelId'],
        optional: ['endDate', 'includeMetadata', 'language', 'managedContentIds', 'managedContentType', 'page', 'pageSize', 'startDate']
    }
};
function createResourceParams$1(config) {
    return {
        urlParams: {
            channelId: config.channelId
        },
        queryParams: {
            endDate: config.endDate, includeMetadata: config.includeMetadata, language: config.language, managedContentIds: config.managedContentIds, managedContentType: config.managedContentType, page: config.page, pageSize: config.pageSize, startDate: config.startDate
        }
    };
}
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    const untrustedConfig_channelId = untrustedConfig.channelId;
    if (typeof untrustedConfig_channelId === 'string') {
        config.channelId = untrustedConfig_channelId;
    }
    const untrustedConfig_endDate = untrustedConfig.endDate;
    if (typeof untrustedConfig_endDate === 'string') {
        config.endDate = untrustedConfig_endDate;
    }
    const untrustedConfig_includeMetadata = untrustedConfig.includeMetadata;
    if (typeof untrustedConfig_includeMetadata === 'boolean') {
        config.includeMetadata = untrustedConfig_includeMetadata;
    }
    const untrustedConfig_language = untrustedConfig.language;
    if (typeof untrustedConfig_language === 'string') {
        config.language = untrustedConfig_language;
    }
    const untrustedConfig_managedContentIds = untrustedConfig.managedContentIds;
    if (ArrayIsArray(untrustedConfig_managedContentIds)) {
        const untrustedConfig_managedContentIds_array = [];
        for (let i = 0, arrayLength = untrustedConfig_managedContentIds.length; i < arrayLength; i++) {
            const untrustedConfig_managedContentIds_item = untrustedConfig_managedContentIds[i];
            if (typeof untrustedConfig_managedContentIds_item === 'string') {
                untrustedConfig_managedContentIds_array.push(untrustedConfig_managedContentIds_item);
            }
        }
        config.managedContentIds = untrustedConfig_managedContentIds_array;
    }
    const untrustedConfig_managedContentType = untrustedConfig.managedContentType;
    if (typeof untrustedConfig_managedContentType === 'string') {
        config.managedContentType = untrustedConfig_managedContentType;
    }
    const untrustedConfig_page = untrustedConfig.page;
    if (typeof untrustedConfig_page === 'number' && Math.floor(untrustedConfig_page) === untrustedConfig_page) {
        config.page = untrustedConfig_page;
    }
    const untrustedConfig_pageSize = untrustedConfig.pageSize;
    if (typeof untrustedConfig_pageSize === 'number' && Math.floor(untrustedConfig_pageSize) === untrustedConfig_pageSize) {
        config.pageSize = untrustedConfig_pageSize;
    }
    const untrustedConfig_startDate = untrustedConfig.startDate;
    if (typeof untrustedConfig_startDate === 'string') {
        config.startDate = untrustedConfig_startDate;
    }
    return config;
}
function validateAdapterConfig$1(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$1(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot$1(lds, config) {
    const resourceParams = createResourceParams$1(config);
    const selector = {
        recordId: keyBuilder$1(resourceParams),
        node: select$3(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess$1(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess$1(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError$1(lds, config, resourceParams, response) {
    const snapshot = ingestError$1(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot$1(lds, config, override) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot$1(lds, config, snapshot) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
const listContentAdapterFactory = (lds) => function listContent(untrustedConfig) {
    const config = validateAdapterConfig$1(untrustedConfig, listContent_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot$1(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot$1(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot$1(lds, config);
};

const getDeliveryChannels = createWireAdapterConstructor(adapterName, getDeliveryChannelsAdapterFactory);
const listContent = createWireAdapterConstructor(adapterName$1, listContentAdapterFactory);

export { getDeliveryChannels, listContent };
