---
examples:
 - name: basic
   label: Button Icon Variants
   description: Button icons with multiple variants.
 - name: sizes
   label: Button Icon Sizes
   description: Button icons with multiple sizes.
 - name: inverse
   label: Button Icons with Inverse Variants
   description: Button icons with two types of inverse variants to display on a dark background.
---
A `lightning-button-icon` component represents an icon-only button element that
executes an action in a controller. Clicking the button triggers the JavaScript
method set for `onclick`.

Here is an example.

```html
<template>
    <lightning-button-icon
        icon-name="utility:close"
        variant="bare"
        onclick={handleClick}
        alternative-text="Close window">
    </lightning-button-icon>
</template>
```

#### Component Styling

`lightning-button-icon` implements the
[button icons](https://www.lightningdesignsystem.com/components/button-icons/) blueprint in the Salesforce Lightning Design System (SLDS).

You can use a combination of the `icon-class`, `size`, and `variant`
attributes to customize the button and icon styles. 

 To customize styling on the icon element, use the
`icon-class` attribute. This example creates an icon-only button with bare
variant and icon styling. Only SLDS utility classes are currently supported with `icon-class`.

```html
    <lightning-button-icon
        icon-name="utility:settings"
        variant="bare"
        alternative-text="Settings"
        icon-class="slds-m-around_medium">
    </lightning-button-icon>
```

##### Icons

Use the `icon-name` attribute to add a utility icon to the button.

The SLDS utility icon category offers nearly 200 utility
icons that can be used in `lightning-button-icon`. Although SLDS provides several categories of icons, only the utility category can be used in `lightning-button-icon`.

Visit [utility icons](https://lightningdesignsystem.com/icons/#utility) to view the utility icons.

When applying SLDS classes or icons, check that they are
available in the SLDS release tied to your org. The latest
SLDS resources become available only when the new release
is available in your org.

##### Variants

Use the `variant` attribute with one of these values to apply styling.

* `bare` displays an icon without a container or border
* `bare-inverse` displays an icon in white color without a container or border, useful for dark backgrounds
* `border` is the default variant, an icon in a transparent container with a border
* `border-filled` displays an icon in a filled container with a border
* `border-inverse` displays an icon in a transparent container with a border, useful for dark backgrounds
* `brand` displays an icon in white color in a blue container with a blue border 
* `container` displays an icon in a transparent container without a border

For the `bare` and `bare-inverse` variants, the `size` class applies to the icon itself. For all other variants, the `size` class applies to the button.

##### Sizes

Adjust the button and icon sizes using the `size` attribute with one of these values.

For `bare` and `bare-inverse` variants:
* `medium` is the default size, which creates a 14px by 14px icon
* `small` creates a 12px by 12px icon
* `x-small` creates a 8px by 8px icon
* `large` creates a 24px by 24px icon

For other variants:
* `medium` is the default size, which creates a 32px by 32px button enclosing a 14px by 14px icon.
* `small` creates a 24px by 24px button enclosing a 14px by 14px icon
* `x-small` creates a 20px by 20px button enclosing a 12px by 12px icon
* `xx-small` creates a 16px by 16px button enclosing a 8px by 8px icon

##### Customize Component Styling

To apply additional styling, use the SLDS [utility classes](https://www.lightningdesignsystem.com/utilities/alignment)  with the `class` attribute.

This example adds a margin to the left of the second button using the `slds-m-left_xx-small` class.

```html
<lightning-button-icon icon-name="utility:zoomin"
    alternative-text="Zoom in"
    title="Zoom in"></lightning-button-icon>
<lightning-button-icon icon-name="utility:zoomout"
    alternative-text="Zoom out"
    title="Zoom out"
    class="slds-m-left_xx-small"></lightning-button-icon>
```

To change the border radius of the button, define a custom class using the `class` attribute. This example makes the button border round.

```html
<lightning-button-icon icon-name="utility:zoomin"
        alternative-text="Zoom in"
        title="Zoom in" 
        class="my-round-button"></lightning-button-icon>
```

Specify the border radius using the `--sds-c-button-radius-border` custom property.

```css
.my-round-button {
    --sds-c-button-radius-border: 20px;
}
```

For more information, see [Style Components Using Lightning Design System Styling Hooks](docs/component-library/documentation/lwc/lwc.create_components_css_custom_properties) in the Lightning Web Components Developer Guide.

#### Usage Considerations

Icons are not available in Lightning Out, but they are available in Lightning Components for Visualforce and other experiences.

#### Accessibility

Use the `alternative-text` attribute to describe the icon. The description
should indicate what happens when you click the button, for example 'Upload
File', not what the icon looks like, 'Paperclip'.